@@ -55,8 +55,8 @@ def loadLemmas():
 def loadWF():
     wfs,spells = loadOrthWF()
     wfs,trans = loadTransWF(wfs)
-    spells = [(i+1,v) for i,v in spells]
-    trans = [(i+1,v) for i,v in trans]
+    spells = [(i+1,v) for i,v in enumerate(spells)]
+    trans = [(i+1,v) for i,v in enumerate(trans)]
     return wfs,spells,trans
 
 @task()
